"use strict";

var _hapi = _interopRequireDefault(require("@hapi/hapi"));

var _index = _interopRequireDefault(require("../index"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createServerWithPlugin(options) {
  const server = new _hapi.default.Server();
  server.register({
    plugin: _index.default,
    options
  });
  return {
    server
  };
}

describe('HapiAxiosErrors', () => {
  it('should be a Hapi plugin', () => {
    expect(_index.default.register).toBeInstanceOf(Function);
    expect(_index.default.pkg.name).toBe('@softonic/hapi-axios-errors');
  });
  describe('when it is registered', () => {
    it('should ignore non-error responses', async () => {
      const {
        server
      } = createServerWithPlugin();
      server.route({
        method: 'GET',
        path: '/',
        handler: () => 'ok'
      });
      const response = await server.inject({
        method: 'GET',
        url: '/'
      });
      expect(response.statusCode).toBe(200);
      expect(response.result).toBe('ok');
    });
    it('should ignore non-axios responses', async () => {
      const {
        server
      } = createServerWithPlugin();
      server.route({
        method: 'GET',
        path: '/error',
        handler: () => new Error('foo')
      });
      const notFoundResponse = await server.inject({
        method: 'GET',
        url: '/notFound'
      });
      expect(notFoundResponse.statusCode).toBe(404);
      const errorResponse = await server.inject({
        method: 'GET',
        url: '/error'
      });
      expect(errorResponse.statusCode).toBe(500);
    });
    it('should propagate axios error status codes', async () => {
      const {
        server
      } = createServerWithPlugin();
      server.route({
        method: 'GET',
        path: '/',
        handler: () => {
          const axiosError = new Error('Axios error');
          axiosError.response = {
            status: 400
          };
          return axiosError;
        }
      });
      const response = await server.inject({
        method: 'GET',
        url: '/'
      });
      expect(response.statusCode).toBe(400);
    });
  });
});
//# sourceMappingURL=index.spec.js.map